@@ -1,4 +1,8 @@
 #!/usr/bin/python
+#
+# SPDX-License-Identifier: GPL-2.0-only
+# (c) 2023 Gerd Hoffmann
+#
 """ print and edit ovmf varstore files """
 import sys
 import json
@@ -10,8 +14,9 @@ from virt.firmware.efi import efijson
 from virt.firmware.efi import devpath
 from virt.firmware.efi import ucs16
 
-from virt.firmware.varstore import edk2
 from virt.firmware.varstore import aws
+from virt.firmware.varstore import jstore
+from virt.firmware.varstore import autodetect
 
 
 ##################################################################################################
@@ -139,23 +144,15 @@ def main():
     logging.basicConfig(format = '%(levelname)s: %(message)s',
                         level = getattr(logging, options.loglevel.upper()))
 
-    edk2store = None
-    awsstore = None
+    varstore = None
     varlist = efivar.EfiVarList()
 
     if options.input:
-        if edk2.Edk2VarStore.probe(options.input):
-            edk2store = edk2.Edk2VarStore(options.input)
-            varlist = edk2store.get_varlist()
-        elif edk2.Edk2VarStoreQcow2.probe(options.input):
-            edk2store = edk2.Edk2VarStoreQcow2(options.input)
-            varlist = edk2store.get_varlist()
-        elif aws.AwsVarStore.probe(options.input):
-            awsstore = aws.AwsVarStore(options.input)
-            varlist = awsstore.get_varlist()
-        else:
+        varstore = autodetect.open_varstore(options.input)
+        if varstore is None:
             logging.error("unknown input file format")
             sys.exit(1)
+        varlist = varstore.get_varlist()
 
     if options.extract:
         for (key, item) in varlist.items():
@@ -277,10 +274,8 @@ def main():
             varlist.print_compact()
 
     if options.output:
-        if edk2store:
-            edk2store.write_varstore(options.output, varlist)
-        elif awsstore:
-            awsstore.write_varstore(options.output, varlist)
+        if varstore:
+            varstore.write_varstore(options.output, varlist)
         else:
             logging.error("no input file specified (needed as edk2 varstore template)")
             sys.exit(1)
@@ -292,13 +287,10 @@ def main():
             aws.AwsVarStore.write_varstore(options.output_aws, varlist)
 
     if options.output_json:
-        j = json.dumps(varlist, cls=efijson.EfiJSONEncoder, indent = 4)
         if options.output_json == "-":
-            print(j)
+            print(jstore.JsonVarStore.json_varstore(varlist))
         else:
-            logging.info('writing json varstore to %s', options.output_json)
-            with open(options.output_json, "w", encoding = 'utf-8') as f:
-                f.write(j)
+            jstore.JsonVarStore.write_varstore(options.output_json, varlist)
 
     return 0
 
