@@ -1,2 +1,2 @@
 """ Tools for efi (pe) binaries """
-__all__ = [ "peutil" ]
+__all__ = [ "peutils" ]
